@@ -1,16 +1,17 @@
 update_freq <- function(tripid, new_stoptimes, gtfs_data, all_tripids){
   # Update new_stoptimes
   new_stoptimes <- update_dt(tripid, data.table::copy(new_stoptimes)
-                              , gtfs_data
-                              , all_tripids)
+                             , gtfs_data
+                             , all_tripids)
   if(is.null(new_stoptimes)){
     return(new_stoptimes) # nocov
   }
   
-  if(is.null(gtfs_data$frequencies)) {
+  if (test_gtfs_freq(gtfs_data) =='simple') {
     new_stoptimes[, trip_number := tripid ]
     return(new_stoptimes) # nocov
   }  
+  
   #  Get freq info for that trip
   # tripid <- "8700-21-0"
   freq_temp <- subset(gtfs_data$frequencies, trip_id == all_tripids[tripid])
@@ -122,28 +123,28 @@ update_dt <- function(tripid, new_stoptimes, gtfs_data, all_tripids){
   new_points <- data.table::copy(new_stoptimes[lim0, ])
   new_points[, departure_time := arrival_time]
   new_points[, id := id - 0.1]
-
+  
   new_stoptimes[lim0, dist := 0]
-
+  
   new_stoptimes <- rbind(new_stoptimes, new_points)
   data.table::setorder(new_stoptimes, "id")
   new_stoptimes$id <- 1:dim(new_stoptimes)[1]
-
+  
   new_stoptimes[, timestamp := data.table::as.ITime(departure_time)]
-
+  
   new_stoptimes[1, speed := 1e-12]
   new_stoptimes[lim0 + 1, speed := 1e-12]
   new_stoptimes[, cumtime := 0]
   new_stoptimes[, time := 0]
   
   last_point_was_stop <- FALSE
-
+  
   lim0 <- new_stoptimes[ !is.na(timestamp) & !is.na(stop_id), id]
   #  function for speed estimation
   update_speeds <- function(i){
     a <- lim0[i]
     b <- lim0[i + 1]
-
+    
     diff_timestamp <- new_stoptimes$timestamp[b] - new_stoptimes$timestamp[a]
     if(diff_timestamp < 0) diff_timestamp <- diff_timestamp + 86400 # one day in seconds
     
@@ -154,15 +155,15 @@ update_dt <- function(tripid, new_stoptimes, gtfs_data, all_tripids){
       new_stoptimes[b, speed := 1e-12]
       return() # two consecutive points with arrival_time don't need to be interpolated
     }
-
+    
     new_speed <- (new_stoptimes$cumdist[b] - new_stoptimes$cumdist[a]) / as.numeric(diff_timestamp) # m/s
-
+    
     new_stoptimes[a:b, speed := 3.6 * new_speed] # km/h
     
     time_a <- new_stoptimes[a, cumtime]
     
     new_stoptimes[a:b, time := (cumdist - data.table::shift(cumdist, 1)) / new_speed]
-
+    
     new_stoptimes[a, time := time_a] # necessary because the shift above will produce NA
     
     new_stoptimes[a:b, cumtime := cumsum(time)]
@@ -174,7 +175,7 @@ update_dt <- function(tripid, new_stoptimes, gtfs_data, all_tripids){
   }
   
   lapply(1:(length(lim0) - 1), FUN = update_speeds)
-
+  
   new_stoptimes[is.na(speed), cumtime := NA]
   new_stoptimes[, time := NULL]
   
@@ -184,7 +185,7 @@ update_dt <- function(tripid, new_stoptimes, gtfs_data, all_tripids){
   #new_stoptimes[is.na(lag), lag := 0]
   # Speed info that was missing (either before or after 1st/last stops)
   # Get trip duration in seconds
-#  new_stoptimes[, cumtime := cumsum(3.6 * dist / speed)]
+  #  new_stoptimes[, cumtime := cumsum(3.6 * dist / speed)]
   
   # reorder columns
   data.table::setcolorder(new_stoptimes, c("trip_id", "route_type", "id", 
@@ -194,28 +195,28 @@ update_dt <- function(tripid, new_stoptimes, gtfs_data, all_tripids){
                                            "speed", "cumtime"))
   
   # distance from trip start to 1st stop
-#  dist_1st <- new_stoptimes[id == lim0[1]]$cumdist # in m
+  #  dist_1st <- new_stoptimes[id == lim0[1]]$cumdist # in m
   
   # get the depart/arrival time from 1st stop
   #departtime_1st <- as.numeric(new_stoptimes[id == lim0[1]]$departure_time)
   #departtime_1st <- departtime_1st - (3.6 * dist_1st / new_stoptimes$speed[1]) # time in seconds
-#  arrival_1st <- as.numeric(new_stoptimes[id == lim0[1]]$arrival_time)
-#  arrival_1st <- arrival_1st - (3.6 * dist_1st / new_stoptimes$speed[1]) # time in seconds
+  #  arrival_1st <- as.numeric(new_stoptimes[id == lim0[1]]$arrival_time)
+  #  arrival_1st <- arrival_1st - (3.6 * dist_1st / new_stoptimes$speed[1]) # time in seconds
   
   
   # Determine the start time of the trip (time stamp the 1st GPS point of the trip)
   #suppressWarnings(new_stoptimes[id == 1, departure_time := round(departtime_1st)])
-#  suppressWarnings(new_stoptimes[id == lim0[1], arrival_time := round(arrival_1st)]) 
+  #  suppressWarnings(new_stoptimes[id == lim0[1], arrival_time := round(arrival_1st)]) 
   
   # recalculate time stamps, except the given 'departure_time's from stop sequences
   #stop_id_nok <- which(is.na(new_stoptimes$departure_time))
   # update indexes in 'newstoptimes'
- # new_stoptimes[, departure_time := departure_time[lim0[1]] +  cumtime + cumsum(lag)]
-#  new_stoptimes[, arrival_time := departure_time - lag]
+  # new_stoptimes[, departure_time := departure_time[lim0[1]] +  cumtime + cumsum(lag)]
+  #  new_stoptimes[, arrival_time := departure_time - lag]
   
   # round
-#  new_stoptimes[, timestamp := round(timestamp)]
-#  new_stoptimes[, arrival_time := round(arrival_time)]
+  #  new_stoptimes[, timestamp := round(timestamp)]
+  #  new_stoptimes[, arrival_time := round(arrival_time)]
   
   if(is.null(new_stoptimes)){
     message(paste0("Could not create stop times for trip '", 
@@ -226,4 +227,4 @@ update_dt <- function(tripid, new_stoptimes, gtfs_data, all_tripids){
                    "' has zero GPS points. Ignoring it.")) # nocov
   
   return(new_stoptimes)
-}
+}
\ No newline at end of file
